# mstr_jupyter

This is Jupyter Notebook extension allowing you to import/export data from/to MicroStrategy.

# Installation
## pip

1. clone repository

    `git clone https://github.microstrategy.com/Kiai/connector-jupyter`

2. install package

    `pip install -e connector-jupyter/production`

    `jupyter-nbextension install mstr_jupyter --py --sys-prefix`

3. enable extension in Jupyter Notebook

    `jupyter-nbextension enable mstr_jupyter --py --sys-prefix`

